==> nextcloud-28.0.3.tgz: nextcloud/apps/systemtags/l10n/fi.js <==
OC.L10N.register(
    "systemtags",
    {
    "System tag %1$s added by the system" : "Järjestelmätunniste %1$s lisätty järjestelmän toimesta",
    "Added system tag {systemtag}" : "Järjestelmätunniste {systemtag} lisättiin",
    "Added system tag %1$s" : "Järjestelmätunniste %1$s lisättiin",
    "%1$s added system tag %2$s" : "%1$s lisäsi järjestelmätunnisteen %2$s",
    "{actor} added system tag {systemtag}" : "{actor} lisäsi järjestelmätunnisteen {systemtag}",
    "System tag %1$s removed by the system" : "Järjestelmätunniste %1$s poistettu järjestelmän toimesta",
    "Removed system tag {systemtag}" : "Järjestelmätunniste {systemtag} poistettiin",
    "Removed system tag %1$s" : "Järjestelmätunniste %1$s poistettiin",
    "%1$s removed system tag %2$s" : "%1$s poisti järjestelmätunnisteen %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} poisti järjestelmätunnisteen {systemtag}",
    "You created system tag %1$s" : "Loit järjestelmätunnisteen %1$s",
    "You created system tag {systemtag}" : "Loit järjestelmätunnisteen {systemtag}",
    "%1$s created system tag %2$s" : "%1$s loi järjestelmätunnisteen %2$s",
    "{actor} created system tag {systemtag}" : "{actor} loi järjestelmätunnisteen {systemtag}",
    "You deleted system tag %1$s" : "Poistit järjestelmätunnisteen %1$s",
    "You deleted system tag {systemtag}" : "Poistit järjestelmätunnisteen {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s poisti järjestelmätunnisteen %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} poisti järjestelmätunnisteen {systemtag}",
    "You updated system tag %2$s to %1$s" : "Päivitit järjestelmätunnisteen %2$s tunnisteeksi %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Päivitit järjestelmätunnisteen {oldsystemtag} tunnisteeksi  {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s päivitti järjestelmätunnisteen %3$s tunnisteeksi %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} päivitti järjestelmätunnisteen {oldsystemtag} tunnisteeksi {newsystemtag}",
    "System tag %2$s was added to %1$s by the system" : "Järjestelmätunniste %2$s lisättiin kohteeseen %1$s järjestelmän toimesta",
    "System tag {systemtag} was added to {file} by the system" : "Järjestelmätunniste {systemtag} lisättiin tiedostoon {file} järjestelmän toimesta",
    "You added system tag %2$s to %1$s" : "Lisäsit järjestelmätunnisteen %2$s tiedostoon %1$s",
    "You added system tag {systemtag} to {file}" : "Lisäsit järjestelmätunnisteen {systemtag} tiedostoon {file}",
    "%1$s added system tag %3$s to %2$s" : "%1$s lisäsi järjestelmätunnisteen %3$s tiedostoon %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} lisäsi järjestelmätunnisteen {systemtag} tiedostoon {file}",
    "System tag %2$s was removed from %1$s by the system" : "Järjestelmätunniste %2$s poistettiin kohteesta %1$s järjestelmän toimesta",
    "System tag {systemtag} was removed from {file} by the system" : "Järjestelmätunniste {systemtag} poistettiin tiedostosta {file} järjestelmän toimesta",
    "You removed system tag %2$s from %1$s" : "Poistit järjestelmätunnisteen %2$s tiedostosta %1$s",
    "You removed system tag {systemtag} from {file}" : "Poistit järjestelmätunnisteen {systemtag} tiedostosta {file}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s poisti järjestelmätunnisteen %3$s tiedostosta %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} poisti järjestelmätunnisteen {systemtag} tiedostosta {file}",
    "%s (restricted)" : "%s (rajoitettu)",
    "%s (invisible)" : "%s (näkymätön)",
    "<strong>System tags</strong> for a file have been modified" : "Tiedoston <strong>järjestelmätunnisteita</strong> on muokattu",
    "Tags" : "Tunnisteet",
    "All tagged %s …" : "Kaikki tunnisteella %s …",
    "Collaborative tags" : "Yhteistyölliset tunnisteet",
    "Collaborative tags …" : "Yhteistyölliset tunnisteet…",
    "Create" : "Luo",
    "Update" : "Päivitys",
    "Delete" : "Poista",
    "Reset" : "Palauta",
    "Loading …" : "Ladataan…",
    "Public" : "Julkinen",
    "Restricted" : "Rajoitettu",
    "Invisible" : "Näkymätön",
    "Loading collaborative tags …" : "Ladataan yhteistyöllisiä tunnisteita…",
    "Search or create collaborative tags" : "Etsi tai luo yhteistyötunnisteita",
    "Failed to load tags" : "Tunnisteiden lataaminen epäonnistui",
    "This file has the tag {tag}" : "Tällä tiedostolla on tunniste {tag}",
    "This file has the tags {firstTags} and {lastTag}" : "Tällä tiedostolla on tunnisteet {firstTags} ja {lastTag}",
    "No tags found" : "Tunnisteita ei löytynyt",
    "Missing \"Content-Location\" header" : "\"Content-Location\"-otsake puuttuu",
    "Tag name is empty" : "Tunnisteen nimi on tyhjä",
    "Select tag …" : "Valitse tunniste ...",
    "Collaborative tagging functionality which shares tags among users." : "Yhteisöllistä tunnistetoiminnallisuutta, lopputuloksena tunnisteet jaetaan käyttäjien kesken.",
    "Tagged files" : "Tunnisteella merkityt tiedostot",
    "Select tags to filter by" : "Valitse suodatettavat tunnisteet",
    "Please select tags to filter by" : "Valitse suodatettavat tunnisteet",
    "No files found for the selected tags" : "Tiedostoja ei löytynyt valituilla tunnisteilla",
    "Create a new tag" : "Luo uusi tunniste",
    "Name" : "Nimi",
    "No files in here" : "Täällä ei ole tiedostoja",
    "No entries found in this folder" : "Ei kohteita tässä kansiossa",
    "Size" : "Koko",
    "Modified" : "Muokattu"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-28.0.7.tgz: nextcloud/apps/systemtags/l10n/fi.js <==
OC.L10N.register(
    "systemtags",
    {
    "System tag %1$s added by the system" : "Järjestelmätunniste %1$s lisätty järjestelmän toimesta",
    "Added system tag {systemtag}" : "Järjestelmätunniste {systemtag} lisättiin",
    "Added system tag %1$s" : "Järjestelmätunniste %1$s lisättiin",
    "%1$s added system tag %2$s" : "%1$s lisäsi järjestelmätunnisteen %2$s",
    "{actor} added system tag {systemtag}" : "{actor} lisäsi järjestelmätunnisteen {systemtag}",
    "System tag %1$s removed by the system" : "Järjestelmätunniste %1$s poistettu järjestelmän toimesta",
    "Removed system tag {systemtag}" : "Järjestelmätunniste {systemtag} poistettiin",
    "Removed system tag %1$s" : "Järjestelmätunniste %1$s poistettiin",
    "%1$s removed system tag %2$s" : "%1$s poisti järjestelmätunnisteen %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} poisti järjestelmätunnisteen {systemtag}",
    "You created system tag %1$s" : "Loit järjestelmätunnisteen %1$s",
    "You created system tag {systemtag}" : "Loit järjestelmätunnisteen {systemtag}",
    "%1$s created system tag %2$s" : "%1$s loi järjestelmätunnisteen %2$s",
    "{actor} created system tag {systemtag}" : "{actor} loi järjestelmätunnisteen {systemtag}",
    "You deleted system tag %1$s" : "Poistit järjestelmätunnisteen %1$s",
    "You deleted system tag {systemtag}" : "Poistit järjestelmätunnisteen {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s poisti järjestelmätunnisteen %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} poisti järjestelmätunnisteen {systemtag}",
    "You updated system tag %2$s to %1$s" : "Päivitit järjestelmätunnisteen %2$s tunnisteeksi %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Päivitit järjestelmätunnisteen {oldsystemtag} tunnisteeksi  {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s päivitti järjestelmätunnisteen %3$s tunnisteeksi %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} päivitti järjestelmätunnisteen {oldsystemtag} tunnisteeksi {newsystemtag}",
    "System tag %2$s was added to %1$s by the system" : "Järjestelmätunniste %2$s lisättiin kohteeseen %1$s järjestelmän toimesta",
    "System tag {systemtag} was added to {file} by the system" : "Järjestelmätunniste {systemtag} lisättiin tiedostoon {file} järjestelmän toimesta",
    "You added system tag %2$s to %1$s" : "Lisäsit järjestelmätunnisteen %2$s tiedostoon %1$s",
    "You added system tag {systemtag} to {file}" : "Lisäsit järjestelmätunnisteen {systemtag} tiedostoon {file}",
    "%1$s added system tag %3$s to %2$s" : "%1$s lisäsi järjestelmätunnisteen %3$s tiedostoon %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} lisäsi järjestelmätunnisteen {systemtag} tiedostoon {file}",
    "System tag %2$s was removed from %1$s by the system" : "Järjestelmätunniste %2$s poistettiin kohteesta %1$s järjestelmän toimesta",
    "System tag {systemtag} was removed from {file} by the system" : "Järjestelmätunniste {systemtag} poistettiin tiedostosta {file} järjestelmän toimesta",
    "You removed system tag %2$s from %1$s" : "Poistit järjestelmätunnisteen %2$s tiedostosta %1$s",
    "You removed system tag {systemtag} from {file}" : "Poistit järjestelmätunnisteen {systemtag} tiedostosta {file}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s poisti järjestelmätunnisteen %3$s tiedostosta %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} poisti järjestelmätunnisteen {systemtag} tiedostosta {file}",
    "%s (restricted)" : "%s (rajoitettu)",
    "%s (invisible)" : "%s (näkymätön)",
    "<strong>System tags</strong> for a file have been modified" : "Tiedoston <strong>järjestelmätunnisteita</strong> on muokattu",
    "Tags" : "Tunnisteet",
    "All tagged %s …" : "Kaikki tunnisteella %s …",
    "Collaborative tags" : "Yhteistyölliset tunnisteet",
    "Create or edit tags" : "Luo tai muokkaa tunnisteita",
    "Search for a tag to edit" : "Etsi tunnistetta muokkausta varten",
    "Collaborative tags …" : "Yhteistyölliset tunnisteet…",
    "Tag name" : "Tunnisteen nimi",
    "Tag level" : "Tunnisteen taso",
    "Create" : "Luo",
    "Update" : "Päivitys",
    "Delete" : "Poista",
    "Reset" : "Palauta",
    "Loading …" : "Ladataan…",
    "Public" : "Julkinen",
    "Restricted" : "Rajoitettu",
    "Invisible" : "Näkymätön",
    "Failed to create tag" : "Tunnisteen luominen epäonnistui",
    "Failed to update tag" : "Tunnisteen päivittäminen epäonnistui",
    "Failed to delete tag" : "Tunnisteen poistaminen epäonnistui",
    "Loading collaborative tags …" : "Ladataan yhteistyöllisiä tunnisteita…",
    "Search or create collaborative tags" : "Etsi tai luo yhteistyötunnisteita",
    "Failed to load tags" : "Tunnisteiden lataaminen epäonnistui",
    "Failed to select tag" : "Tunnisteen valitseminen epäonnistui",
    "This file has the tag {tag}" : "Tällä tiedostolla on tunniste {tag}",
    "This file has the tags {firstTags} and {lastTag}" : "Tällä tiedostolla on tunnisteet {firstTags} ja {lastTag}",
    "No tags found" : "Tunnisteita ei löytynyt",
    "Tags you have created will show up here." : "Luomasi tunnisteet näkyvät täällä.",
    "Missing \"Content-Location\" header" : "\"Content-Location\"-otsake puuttuu",
    "Tag name is empty" : "Tunnisteen nimi on tyhjä",
    "Select tag …" : "Valitse tunniste ...",
    "Collaborative tagging functionality which shares tags among users." : "Yhteisöllistä tunnistetoiminnallisuutta, lopputuloksena tunnisteet jaetaan käyttäjien kesken.",
    "Tagged files" : "Tunnisteella merkityt tiedostot",
    "Select tags to filter by" : "Valitse suodatettavat tunnisteet",
    "Please select tags to filter by" : "Valitse suodatettavat tunnisteet",
    "No files found for the selected tags" : "Tiedostoja ei löytynyt valituilla tunnisteilla",
    "Create a new tag" : "Luo uusi tunniste",
    "Name" : "Nimi",
    "No files in here" : "Täällä ei ole tiedostoja",
    "No entries found in this folder" : "Ei kohteita tässä kansiossa",
    "Size" : "Koko",
    "Modified" : "Muokattu"
},
"nplurals=2; plural=(n != 1);");
